#include "pwqdialog.h"
#include "ui_pwqdialog.h"
#include <pwd.h>
//#include <crypt.h>

PWQDialog::PWQDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::PWQDialog)
{
    ui->setupUi(this);
}

PWQDialog::~PWQDialog()
{
    delete ui;
}


void PWQDialog::pwCheck()
{
    struct passwd *p;
    p=getpwnam("root");
    QString test=ui->lineEdit->text();
    QString check;
    check=((char*)crypt(test.toStdString().c_str(),p->pw_passwd));
    if ( check.contains(p->pw_passwd) )
        this->accept();
    else this->accept(); //reject
}
